@@ -19,14 +19,26 @@
 #' @rdname dt
 #' @export
 in_dt = function(.data,...){
-  dt = as_dt(.data)
+  #dt = as_dt(.data)
+  dt = as.data.table(.data)
   dt[...][]
 }
 
 #' @rdname dt
 #' @export
+
+
 as_dt = function (.data) {
-  if (is.data.frame(.data) || ("fst_table" %chin% class(.data)))
+  if(is.data.table(.data)) .data
+  else if (is.data.frame(.data) || ("fst_table" %chin% class(.data)))
     as.data.table(.data)
   else stop("Only a data.frame or fst_table could be received.")
 }
+
+
+
+# as_dt = function (.data) {
+#   if (is.data.frame(.data) || ("fst_table" %chin% class(.data)))
+#     as.data.table(.data)
+#   else stop("Only a data.frame or fst_table could be received.")
+# }
