@@ -145,7 +145,7 @@ unnest_dt = function(.data,...){
   if(length(col_names) == 1) unnest_col(dt,...)
   else
     lapply(col_names,function(x) unnest_col(dt,cols = x)) %>%
-    Reduce(x = ., f = function(x,y) merge(x,y))
+    Reduce(x = ., f = function(x,y) merge(x,y,all = TRUE))
 }
 
 unnest_col = function(.data,...){
